@@ -161,8 +161,8 @@ class League:
             league_writer.writerow(['NL Weighted Runs Created', nlWRCList[0], nlWRCList[1], nlWRCList[2]])
             league_writer.writerow(['FIP Constant', League.FIP_Constant])
 
-    @staticmethod
-    def starter():
+    def starter(self):
+        pass
         """
         Initializes the league object, needs to be always be called
         - Gets list of NL and AL teams in addition to each ball park factor
@@ -191,8 +191,8 @@ class League:
         for i in range(14, len(teamList)):
             League.nlTeamList.append(teamList[i])
         # Add a column to the dict for both the NL and AL avg ballpark factor
-        League.ballParkDict.update({"NL Avg": data[0]['NL Basic']})
-        League.ballParkDict.update({"AL Avg": data[0]['AL Basic']})
+        League.ballParkDict.update({"NL Avg": 100.0714286})
+        League.ballParkDict.update({"AL Avg": 99.3125})
 
         # Open csv file
         df = pd.read_csv("leagueConstants.csv")
@@ -317,7 +317,7 @@ class League:
         :return:
         """
         # Create a dictionary of all the games being played today
-        today = statsapi.schedule(date="2021-07-01")
+        today = statsapi.schedule()
         if(len(today)) > 0:
             # Create lists for both the away and home teams
             hTList = []
@@ -1624,4 +1624,4 @@ class League:
         ttFAB = dict(list(League.get_batters(time, 2, qualified=True).items()))
         coldBList2 = dict(sorted(ttFAB.items(), key=lambda item: item[1][6])[0:10])
         print("\n" + "Top 10 Coldest Free Agent Batters: ")
-        League.print_batters(coldBList2, reverse=False)
\ No newline at end of file
+        League.print_batters(coldBList2, reverse=False)
